@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -1394,32 +1394,32 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include/freetype2",
-"/usr/include",
-"/usr/include/freetype2",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libROOTGeomViewer dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomNodeBase;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomNode;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeoItem;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomRenderInfo;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomRawRenderInfo;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomShapeRenderInfo;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomVisible;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomConfig;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomDrawing;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomNodeInfo;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomDescription;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomHierarchy.hxx")))  RGeomHierarchy;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeomViewer.hxx")))  RGeomViewer;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeoPainter.hxx")))  RGeoPainter;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomNodeBase;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomNode;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeoItem;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomRenderInfo;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomRawRenderInfo;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomShapeRenderInfo;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomVisible;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomConfig;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomDrawing;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomNodeInfo;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomData.hxx")))  RGeomDescription;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomHierarchy.hxx")))  RGeomHierarchy;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeomViewer.hxx")))  RGeomViewer;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RGeoPainter.hxx")))  RGeoPainter;}
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libROOTGeomViewer dictionary payload"
@@ -1433,6 +1433,9 @@ namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RGeoPainter.hx
 #ifndef NO_SSL_DL
   #define NO_SSL_DL 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
