@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -1266,30 +1266,30 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include/freetype2",
-"/usr/include",
-"/usr/include/freetype2",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libRecorder dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecEvent;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecCmdEvent;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecExtraEvent;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecGuiEvent;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecWinPair;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorder;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderState;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderReplaying;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderRecording;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderInactive;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderPaused;
-class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TGRecorder;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecEvent;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecCmdEvent;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecExtraEvent;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecGuiEvent;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecWinPair;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorder;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderState;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderReplaying;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderRecording;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderInactive;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TRecorderPaused;
+class  __attribute__((annotate("$clingAutoload$TRecorder.h")))  TGRecorder;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libRecorder dictionary payload"
@@ -1297,6 +1297,9 @@ class __attribute__((annotate("$clingAutoload$TRecorder.h")))  TGRecorder;
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
